# -*- encoding: utf-8 -*-
#
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from sqlalchemy import MetaData
from sqlalchemy import Index
from ceilometer.storage.sqlalchemy.models import Meter

meta = MetaData()


def upgrade(migrate_engine):
    meta.bind = migrate_engine
    index = Index('idx_meter_rid_cname', Meter.resource_id,
                  Meter.counter_name)
    index.create(bind=migrate_engine)


def downgrade(migrate_engine):
    meta.bind = migrate_engine
    index = Index('idx_meter_rid_cname', Meter.resource_id,
                  Meter.counter_name)
    index.drop(bind=migrate_engine)
